unit Blocks;

{$mode ObjFPC}{$H+}

interface

uses
  Classes, SysUtils, Graphics;

type

  { TBlock }

  TBlock = class(TObject)
  private
    FLocation: TPoint;
    FColor: TColor;
    posY, posX, sizeX, sizeY: integer;
    r, g, b: integer;
    blockRect: TRect;
    willMove, FisTouching: boolean;
    function GetColor: TColor;
    function GetLocation: TPoint;
    procedure SetColor(AColor: TColor);

  public
    procedure Draw(Canvas: TCanvas);
    procedure Move(X, Y: integer);
    procedure MouseTouch(x, y: integer);

    property isTouching: boolean read FisTouching write FisTouching;
    property Color: TColor read FColor write FColor;
    property location: TPoint read FLocation;


    constructor Create(Canvas: TCanvas);
    destructor Destroy; override;
  end;

implementation

{ TBlock }

{Setter Getter}
function TBlock.GetLocation: TPoint;
begin
  FLocation := blockRect.Location;
  Result := FLocation;
end;

procedure TBlock.SetColor(AColor: TColor);
begin
  FColor := AColor;
end;

function TBlock.GetColor: TColor;
begin
  Result := FColor;
end;

{procedures}
procedure TBlock.Draw(Canvas: TCanvas);
begin
  Canvas.Brush.Color := FColor;
  Canvas.FillRect(blockRect);
end;

procedure TBlock.Move(X, Y: integer);
begin
  if FisTouching then
  begin
    posX := X - sizeX div 2;
    posY := Y - sizeY div 2;
    blockRect := Rect(posX, posY, posX + sizeX, posY + SizeY);
  end;
end;

procedure TBlock.MouseTouch(x, y: integer);
begin
  if blockRect.Contains(Point(X, Y)) then
  begin
    FisTouching := True;
  end
  else
    FisTouching := False;
end;

constructor TBlock.Create(Canvas: TCanvas);
begin
  r := 246;
  g := 7;
  b := 142;
  willMove := False;
  sizeX := 100;
  sizeY := 100;
  posX := (Canvas.Width div 2) + 100;
  posY := (Canvas.Height div 2) + 100;
  FColor := RGBToColor(r, g, b);
  blockRect := Rect(posX, posY, posX + sizeX, posY + SizeY);
end;

destructor TBlock.Destroy;
begin
  inherited Destroy;
end;

end.
